use regex::Captures;
use eyre::Result;
use super::*;

pub struct EpisodeMarker {}
impl Rule for EpisodeMarker {
    fn check(_filename: &str, captures: &Captures) -> Option<NonCompliantReason> {
        match captures.name("seasonPrefix") {
            Some(marker) => {
                if marker.as_str() != "S" {
                    return Some(NonCompliantReason::InvalidEpisodeMarker("Season Prefix must be 'S'".to_string()))
                }
            }
            None => return Some(NonCompliantReason::InvalidEpisodeMarker("No Season Prefix found".to_string())),
        }

        match captures.name("episodePrefix") {
            Some(marker) => {
                if marker.as_str() != "E" {
                    return Some(NonCompliantReason::InvalidEpisodeMarker("Episode Prefix must be 'E'".to_string()))
                }
            }
            None => return Some(NonCompliantReason::InvalidEpisodeMarker("No Episode Prefix found".to_string())),
        }

        match captures.name("season") {
            Some(marker) => {
                let str = marker.as_str();
                if str.len() != 2 && str.len() != 3 {
                    return Some(NonCompliantReason::InvalidEpisodeMarker("Season should be annotated with either 2 or 3 digits".to_string()))
                }
            }
            None => return Some(NonCompliantReason::InvalidEpisodeMarker("No Season digits found".to_string())),
        }

        match captures.name("episode") {
            Some(marker) => {
                let str = marker.as_str();
                if str.len() != 2 && str.len() != 3 {
                    return Some(NonCompliantReason::InvalidEpisodeMarker("Episode should be annotated with either 2 or 3 digits".to_string()))
                }
            }
            None => return Some(NonCompliantReason::InvalidEpisodeMarker("No Episode digits found".to_string())),
        }

        return None
    }

    fn fix(_filename: &str, _captures: &Captures) -> Result<FixStatus> {
        return Ok(FixStatus::NotImplemented)
    }
}
